core.Table (Table) — amici1

# `core.Table` (Table)

Actions

An `AbstractTable` that works

  on a Django Model using a QuerySet.

  A Table inherits from `AbstractTable` and adds attributes like `model` and `master` and `master_key` who are important because Lino handles relations automagically.

  Another class of attributes are filter, exclude and sort_order which are thin wrappers to Django’s query lookup parameters of same name.

  See `dd.Table`.

## Filter parameters